
#ifndef _C11_ki526_
#define _C11_ki526_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1209_12674(EIF_REFERENCE, EIF_REFERENCE);
extern void F1209_12675(EIF_REFERENCE);
extern void EIF_Minit526(void);
extern char *(*R9437[])();
extern char *(*R9417[])();

#ifdef __cplusplus
}
#endif

#endif
